@@ -7,6 +7,7 @@ import ddddocr
 import os
 import platform
 from PIL import Image
+from selenium.webdriver.common.by import By
 
 ssl._create_default_https_context = ssl._create_unverified_context
 uc.TARGET_VERSION = 91
@@ -158,6 +159,8 @@ class web(object):
 
         if self.site.sitename=='ssd':
             imgs=self.driver.find_elements_by_xpath('/html/body/section/main/div/form/div[3]/span[1]/img')
+        elif self.site.sitename=='hare':
+            imgs=self.driver.find_elements_by_xpath('/html/body/div[3]/form[2]/div[3]/div[2]/img')
         else:
             imgs=self.driver.find_elements_by_xpath('/html/body/table[2]/tbody/tr/td/form[2]/table/tbody/tr[4]/td[2]/img')
 
@@ -225,6 +228,8 @@ class web(object):
             submitxpath='/html/body/table[2]/tbody/tr/td/form[2]/table/tbody/tr[7]/td/input[1]'
         elif self.site.sitename=='pter':
             time.sleep(3)
+        elif self.site.sitename=='hare':
+            submitxpath='/html/body/div[3]/form[2]/div[8]/button[1]'
         elif self.site.sitename=='tjupt':
             submitxpath='/html/body/table[2]/tbody/tr/td/form/table/tbody/tr[5]/td/input[1]'
 
@@ -281,10 +286,10 @@ class web(object):
         except Exception as r:
             logger.warning('打开登录页面发生错误，错误信息: %s' %(r))
             return -1
-
+        '''
         if len(self.driver.find_elements_by_name('username'))<=0:
             self.driver.execute_script("window.scrollBy(0,300)")
-
+        '''
         if not self.wait_page():
             logger.warning('登录页面加载失败')
             return -1
